@@ -53,7 +53,6 @@
 #include <QDir>
 #include <QFileSystemWatcher>
 #include <QKeyEvent>
-#include <QDebug>
 #include <QFileSystemWatcher>
 #include <QMimeDatabase>
 #include <QMimeType>
@@ -172,36 +171,36 @@ void ElisaApplication::setupActions(const QString &actionName)
     if (actionName == QLatin1String("toggle_playlist") && KAuthorized::authorizeAction(actionName)) {
         auto togglePlaylistAction = d->mCollection.addAction(actionName, this, &ElisaApplication::togglePlaylist);
         togglePlaylistAction->setShortcut(QKeySequence(Qt::Key_F9));
-        togglePlaylistAction->setText(i18n("Toggle Playlist"));
+        togglePlaylistAction->setText(i18nc("@action", "Toggle Playlist"));
     }
 
     if (actionName == QLatin1String("Seek") && KAuthorized::authorizeAction(actionName)) {
             auto seekAction = d->mCollection.addAction(actionName, this, &ElisaApplication::seek);
-            seekAction->setText(i18n("Seek forward 10 seconds"));
+            seekAction->setText(i18nc("@action", "Seek forward 10 seconds"));
             d->mCollection.setDefaultShortcut(seekAction, QKeySequence(Qt::SHIFT | Qt::Key_Right));
     }
 
     if (actionName == QLatin1String("Scrub") && KAuthorized::authorizeAction(actionName)) {
             auto scrubAction = d->mCollection.addAction(actionName, this, &ElisaApplication::scrub);
-            scrubAction->setText(i18n("Scrub backwards 10 seconds"));
+            scrubAction->setText(i18nc("@action", "Scrub backwards 10 seconds"));
             d->mCollection.setDefaultShortcut(scrubAction, QKeySequence(Qt::SHIFT | Qt::Key_Left));
     }
 
     if (actionName == QLatin1String("NextTrack") && KAuthorized::authorizeAction(actionName)) {
             auto nextTrackAction = d->mCollection.addAction(actionName, this, &ElisaApplication::nextTrack);
-            nextTrackAction->setText(i18n("Go to next track"));
+            nextTrackAction->setText(i18nc("@action", "Go to next track"));
             d->mCollection.setDefaultShortcut(nextTrackAction, QKeySequence(Qt::CTRL | Qt::Key_Right));
     }
 
     if (actionName == QLatin1String("PreviousTrack") && KAuthorized::authorizeAction(actionName)) {
             auto previousTrackAction = d->mCollection.addAction(actionName, this, &ElisaApplication::previousTrack);
-            previousTrackAction->setText(i18n("Go to previous track"));
+            previousTrackAction->setText(i18nc("@action", "Go to previous track"));
             d->mCollection.setDefaultShortcut(previousTrackAction, QKeySequence(Qt::CTRL | Qt::Key_Left));
     }
 
     if (actionName == QLatin1String("Play-Pause") && KAuthorized::authorizeAction(actionName)) {
             auto playPauseAction = d->mCollection.addAction(actionName, this, &ElisaApplication::playPause);
-            playPauseAction->setText(i18n("Play/pause"));
+            playPauseAction->setText(i18nc("@action", "Play/pause"));
             d->mCollection.setDefaultShortcut(playPauseAction, QKeySequence(Qt::Key_Space));
     }
 
@@ -212,7 +211,7 @@ void ElisaApplication::setupActions(const QString &actionName)
 
     if (actionName == QLatin1String("togglePartyMode") && KAuthorized::authorizeAction(actionName)) {
         auto togglePartyModeAction = d->mCollection.addAction(actionName, this, &ElisaApplication::togglePartyMode);
-        togglePartyModeAction->setText(i18n("Toggle Party Mode"));
+        togglePartyModeAction->setText(i18nc("@action", "Toggle Party Mode"));
         d->mCollection.setDefaultShortcut(togglePartyModeAction, QKeySequence(Qt::Key_F11));
         d->mCollection.addAction(togglePartyModeAction->objectName(), togglePartyModeAction);
     }
@@ -221,30 +220,31 @@ void ElisaApplication::setupActions(const QString &actionName)
 #endif
 }
 
-void ElisaApplication::openFiles(const QList<QUrl> &files)
+bool ElisaApplication::openFiles(const QList<QUrl> &files)
 {
-    openFiles(files, QDir::currentPath());
+    return openFiles(files, QDir::currentPath());
 }
 
-void ElisaApplication::openFiles(const QList<QUrl> &files, const QString &workingDirectory)
+bool ElisaApplication::openFiles(const QList<QUrl> &files, const QString &workingDirectory)
 {
     auto audioFiles = DataTypes::EntryDataList{};
     const QMimeDatabase mimeDB;
     for (const auto &file : files) {
         const QMimeType mime = mimeDB.mimeTypeForUrl(file);
-        if (mime.inherits(QStringLiteral("audio/x-mpegurl"))) {
+        if (ElisaUtils::isPlayList(mime)) {
             d->mMediaPlayListProxyModel->loadPlayList(file);
         } else if (mime.name().startsWith(QStringLiteral("audio/"))) {
             audioFiles.push_back(DataTypes::EntryData{{{DataTypes::ElementTypeRole, ElisaUtils::FileName},
                             {DataTypes::ResourceRole, file}}, {}, {}});
         }
     }
-    audioFiles = checkFileListAndMakeAbsolute(audioFiles, workingDirectory);
-    if (!audioFiles.isEmpty()) {
-        Q_EMIT enqueue(audioFiles,
+    auto filesToOpen = checkFileListAndMakeAbsolute(audioFiles, workingDirectory);
+    if (!filesToOpen.isEmpty()) {
+        Q_EMIT enqueue(filesToOpen,
                        ElisaUtils::PlayListEnqueueMode::AppendPlayList,
                        ElisaUtils::PlayListEnqueueTriggerPlay::TriggerPlay);
     }
+    return (audioFiles.count() == filesToOpen.count());
 }
 
 void ElisaApplication::activateActionRequested(const QString &actionName, const QVariant &parameter)
@@ -467,6 +467,8 @@ void ElisaApplication::initializePlayer()
     QObject::connect(d->mAudioControl.get(), &ManageAudioPlayer::playerSourceChanged, d->mAudioWrapper.get(), &AudioWrapper::setSource);
     QObject::connect(d->mAudioControl.get(), &ManageAudioPlayer::startedPlayingTrack,
                      d->mMusicManager->viewDatabase(), &DatabaseInterface::trackHasStartedPlaying);
+    QObject::connect(d->mAudioControl.get(), &ManageAudioPlayer::finishedPlayingTrack,
+                     d->mMusicManager->viewDatabase(), &DatabaseInterface::trackHasFinishedPlaying);
     QObject::connect(d->mAudioControl.get(), &ManageAudioPlayer::updateData, d->mMediaPlayList.get(), &MediaPlayList::setData);
 
     QObject::connect(d->mMediaPlayListProxyModel.get(), &MediaPlayListProxyModel::ensurePlay, d->mAudioControl.get(), &ManageAudioPlayer::ensurePlay);
@@ -551,7 +553,11 @@ bool ElisaApplication::eventFilter(QObject *object, QEvent *event)
 #if KF5XmlGui_FOUND
     auto *keyEvent = static_cast<QKeyEvent*>(event);
     auto playPauseAction = d->mCollection.action(QStringLiteral("Play-Pause"));
+#if QT_VERSION > QT_VERSION_CHECK(6, 0, 0)
+    if (keyEvent->key() == Qt::Key_Space && playPauseAction->shortcut()[0].key() == Qt::Key_Space) {
+#else
     if (keyEvent->key() == Qt::Key_Space && playPauseAction->shortcut()[0] == Qt::Key_Space) {
+#endif
         return true;
     }
 #else
