@@ -14,11 +14,6 @@
 
 //#define QT_QML_DEBUG
 
-#if KF5Declarative_FOUND
-#include <KDeclarative/KDeclarative>
-#include <KQuickAddons/QtQuickSettings>
-#endif
-
 #include <KLocalizedString>
 #include <KLocalizedContext>
 
@@ -28,27 +23,27 @@
 #include <KCrash>
 #endif
 
-
+#include <KQuickIconProvider>
 #include <QIcon>
 
+#include <QQmlContext>
 #include <QApplication>
 #include <QCommandLineParser>
 #include <QStandardPaths>
+#include <QSurfaceFormat>
 #include <QDir>
 
 #include <QQmlApplicationEngine>
-#include <QJSEngine>
 #include <QQmlFileSelector>
 #include <QQuickStyle>
-#include <QQmlContext>
 
-#if Qt5AndroidExtras_FOUND
+#if QtAndroidExtras_FOUND
 #include <QAndroidService>
 #endif
 
 #include <memory>
 
-#if Qt5AndroidExtras_FOUND
+#if QtAndroidExtras_FOUND
 #include <QAndroidJniObject>
 #include <QtAndroid>
 #endif
@@ -59,6 +54,10 @@ int __attribute__((visibility("default"))) main(int argc, char *argv[])
 int main(int argc, char *argv[])
 #endif
 {
+    auto format = QSurfaceFormat::defaultFormat();
+    format.setOption(QSurfaceFormat::ResetNotification);
+    QSurfaceFormat::setDefaultFormat(format);
+
 #if defined Q_OS_ANDROID
     if(argc > 1 && strcmp(argv[1], "-service") == 0){
         QAndroidService app(argc, argv);
@@ -85,13 +84,9 @@ int main(int argc, char *argv[])
     QApplication::setStyle(QStringLiteral("breeze"));
 #endif
 
-#if KF5Declarative_FOUND
-    KQuickAddons::QtQuickSettings::init();
-#endif
-
     KLocalizedString::setApplicationDomain("elisa");
 
-#if Qt5AndroidExtras_FOUND
+#if QtAndroidExtras_FOUND
     qInfo() << QCoreApplication::arguments();
 
     QAndroidJniObject::callStaticMethod<void>("org/kde/elisa/ElisaService",
@@ -107,20 +102,20 @@ int main(int argc, char *argv[])
     QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("elisa")));
 
     KAboutData aboutData( QStringLiteral("elisa"),
-                          i18n("Elisa"),
+                          i18nc("@title", "Elisa"),
                           QStringLiteral(ELISA_VERSION_STRING),
-                          i18n("A Simple Music Player made with love by the KDE community"),
+                          i18nc("@info", "A Simple Music Player made with love by the KDE community"),
                           KAboutLicense::LGPL_V3,
-                          i18n("(c) 2015-2020, Elisa contributors"));
+                          i18nc("@info", "(c) 2015-2020, Elisa contributors"));
 
-    aboutData.addAuthor(QStringLiteral("Matthieu Gallien"),i18n("Creator"), QStringLiteral("mgallien@mgallien.fr"));
-    aboutData.addAuthor(QStringLiteral("Nate Graham"), i18n("Author"), QStringLiteral("nate@kde.org"));
+    aboutData.addAuthor(QStringLiteral("Matthieu Gallien"),i18nc("@label", "Creator"), QStringLiteral("mgallien@mgallien.fr"));
+    aboutData.addAuthor(QStringLiteral("Nate Graham"), i18nc("@label", "Author"), QStringLiteral("nate@kde.org"));
 
-    aboutData.addCredit(QStringLiteral("Andrew Lake"), i18n("Concept and design work"), QStringLiteral("jamboarder@gmail.com"));
-    aboutData.addCredit(QStringLiteral("Luigi Toscano"), i18n("Localization support"), QStringLiteral("luigi.toscano@tiscali.it"));
-    aboutData.addCredit(QStringLiteral("Safa Alfulaij"), i18n("Right to left support in interface"), QStringLiteral("safa1996alfulaij@gmail.com"));
-    aboutData.addCredit(QStringLiteral("Diego Gangl"), i18n("Various improvements to the interface"), QStringLiteral("diego@sinestesia.co"));
-    aboutData.addCredit(QStringLiteral("Jérôme Guidon"), i18n("Support for online radios"), QStringLiteral("guidon@live.fr"));
+    aboutData.addCredit(QStringLiteral("Andrew Lake"), i18nc("@label", "Concept and design work"), QStringLiteral("jamboarder@gmail.com"));
+    aboutData.addCredit(QStringLiteral("Luigi Toscano"), i18nc("@label", "Localization support"), QStringLiteral("luigi.toscano@tiscali.it"));
+    aboutData.addCredit(QStringLiteral("Safa Alfulaij"), i18nc("@label", "Right to left support in interface"), QStringLiteral("safa1996alfulaij@gmail.com"));
+    aboutData.addCredit(QStringLiteral("Diego Gangl"), i18nc("@label", "Various improvements to the interface"), QStringLiteral("diego@sinestesia.co"));
+    aboutData.addCredit(QStringLiteral("Jérôme Guidon"), i18nc("@label", "Support for online radios"), QStringLiteral("guidon@live.fr"));
 
     KAboutData::setApplicationData(aboutData);
 
@@ -129,23 +124,25 @@ int main(int argc, char *argv[])
     parser.process(app);
     aboutData.processCommandLine(&parser);
 
-#if defined Q_OS_ANDROID
-    QQuickStyle::setStyle(QStringLiteral("Material"));
+
+    // If styling has not been set via QT_QUICK_CONTROLS_STYLE, default to some
+    // styles that make sense for desktop and mobile form factors.
+    if (qEnvironmentVariableIsEmpty("QT_QUICK_CONTROLS_STYLE")) {
+#ifdef Q_OS_ANDROID
+        QQuickStyle::setStyle(QStringLiteral("org.kde.breeze"));
+        QQuickStyle::setFallbackStyle(QStringLiteral("Material"));
 #else
-    QQuickStyle::setStyle(QStringLiteral("org.kde.desktop"));
-    QQuickStyle::setFallbackStyle(QStringLiteral("Fusion"));
+        QQuickStyle::setStyle(QStringLiteral("org.kde.desktop"));
+        QQuickStyle::setFallbackStyle(QStringLiteral("Fusion"));
 #endif
+    }
 
     QQmlApplicationEngine engine;
     engine.addImportPath(QStringLiteral("qrc:/imports"));
     QQmlFileSelector selector(&engine);
 
-#if KF5Declarative_FOUND
-    KDeclarative::KDeclarative decl;
-    decl.setDeclarativeEngine(&engine);
-    decl.setupEngine(&engine);
-    decl.setupContext();
-#endif
+    // Allow image:// icon URLs to be loaded as images im QML
+    engine.addImageProvider(QStringLiteral("icon"), new KQuickIconProvider);
 
     engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
 
