@@ -41,7 +41,7 @@ void AbstractMediaProxyModel::setFilterText(const QString &filterText)
 
     mFilterText = filterText;
 
-    mFilterExpression.setPattern(mFilterText);
+    mFilterExpression.setPattern(mFilterText.normalized(QString::NormalizationForm_KC));
     mFilterExpression.setPatternOptions(QRegularExpression::CaseInsensitiveOption);
     mFilterExpression.optimize();
 
@@ -83,12 +83,12 @@ void AbstractMediaProxyModel::sortModel(Qt::SortOrder order)
 
 void AbstractMediaProxyModel::setPlayList(MediaPlayListProxyModel *playList)
 {
-    disconnectPlayList();
-
     if (mPlayList == playList) {
         return;
     }
 
+    disconnectPlayList();
+
     mPlayList = playList;
     Q_EMIT playListChanged();
 
